@@ -12,5 +12,4 @@ class ExtensionManager(MiddlewareManager):
 
     @classmethod
     def _get_mwlist_from_settings(cls, settings):
-        return build_component_list(settings['EXTENSIONS_BASE'], \
-            settings['EXTENSIONS'])
+        return build_component_list(settings.getwithbase('EXTENSIONS'))
